"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const color_1 = require("@heroku-cli/color");
const base_1 = tslib_1.__importDefault(require("../../../lib/base"));
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const helpers_1 = require("../../../lib/helpers");
const tsheredoc_1 = tslib_1.__importDefault(require("tsheredoc"));
class Create extends base_1.default {
    static description = 'creates a Data Cloud Data Action Target for a Heroku app';
    static flags = {
        app: command_1.flags.app({ required: true }),
        'api-name': command_1.flags.string({ char: 'n', description: 'API name for the Data Action Target, default derived from label' }),
        'org-name': command_1.flags.string({ char: 'o', required: true, description: 'authorized Data Cloud Org instance name where the Data Action Target is created' }),
        'target-api-path': command_1.flags.string({ char: 'p', required: true, description: 'API path for the Data Action Target excluding app URL, eg "/" or "/handleDataCloudDataChangeEvent"' }),
        type: command_1.flags.string({ char: 't', description: 'Data Action Target type', options: ['WebHook'], default: 'WebHook' }),
    };
    static args = {
        label: core_1.Args.string({ required: true, description: 'Data Action Target label' }),
    };
    isPendingState(state) {
        return state !== 'created' && state !== 'creation_failed';
    }
    async run() {
        const { flags, args } = await this.parse(Create);
        const { app, 'org-name': orgName, 'target-api-path': targetPath, type } = flags;
        let { 'api-name': apiName } = flags;
        const { label } = args;
        if (!apiName) {
            // More encoding needed
            apiName = label.replaceAll(' ', '_');
        }
        await this.configureIntegrationClient(app);
        core_1.ux.action.start(`Creating ${color_1.color.app(app)} as '${color_1.color.yellow(label)}' Data Action Target ${type} to ${color_1.color.yellow(orgName)}`);
        let createState;
        const { body: createResp } = await this.integration.post(`/addons/${this.addonId}/connections/datacloud/${orgName}/data_action_targets`, {
            body: {
                api_name: apiName,
                label,
                target_endpoint: targetPath,
                type,
            },
        });
        let { state, error } = createResp;
        while (this.isPendingState(state)) {
            await new Promise(resolve => {
                setTimeout(resolve, 5000);
            });
            ({ body: createState } = await this.integration.get(`/addons/${this.addonId}/connections/datacloud/${orgName}/data_action_targets/${apiName}`));
            // ({state, error} = importState)
            state = createState.state;
            error = createState.error;
            core_1.ux.action.status = (0, helpers_1.humanize)(state);
        }
        core_1.ux.action.stop((0, helpers_1.humanize)(state));
        if (state !== 'created') {
            core_1.ux.error(error === undefined ?
                (0, helpers_1.humanize)(state) :
                (0, tsheredoc_1.default) `
            ${error.id}
            ${error.message}
          `, { exit: 1 });
        }
    }
}
exports.default = Create;
